@@ -6,12 +6,12 @@
 # Author: jianglin
 # Email: xiyang0807@gmail.com
 # Created: 2018-02-26 11:41:17 (CST)
-# Last Update: Wednesday 2018-02-28 15:01:25 (CST)
+# Last Update: Monday 2018-03-19 14:48:43 (CST)
 #          By:
 # Description:
 # ********************************************************************************
 from .element import Org
 
 
-def org_to_html(text, offset=0, toc=True, escape=False):
+def org_to_html(text, offset=0, toc=True, escape=True):
     return Org(text, offset, toc, escape).to_html()
